Miscellaneous modules — summer 0.7.8 documentation

# Miscellaneous modules

## utils – utilities

Utility functions and classes.

## stringutils – string utilities

Utility string functions that should be probably part of Python stdlib.

`EMPTY_STRING` defines an empty string (ie. “”)

This module is not imported into public summer namespace, so you should import it directly:

    from summer import stringutils

## ipythonutils – ipython debugging support

Support for embedded IPython invocation.

This module is not imported into public summer namespace, so you should import it directly:

    from summer import ipythonutils

## ass – assert

Provides various pre-implemented simple tests (ie. asserts) suitable for input argument testing.

This module is not imported into public summer namespace, so you should import it directly:

    from summer import ass

## lod – list of dictionaries

List of dictionaries (lod) – simple yet powerfull in memory data structure, ie. grid.

Thanks to: http://stackoverflow.com/questions/1038160/python-data-structure-for-maintaing-tabular-data-in-memory

This module is not imported into public summer namespace, so you should import it directly:

    from summer import lod